﻿// Copyright (C) 2008 - 2010 CASIO Europe GmbH
//
// This file is part of SoftkeysWM.
//
// SoftkeysWM is provided AS IS for educational purposes only,
// with no warranties, and confers no rights. Error checking is 
// elided for clarity. Carry out sufficient tests prior to using
// it in a productive environment.
// CASIO Europe GmbH accepts no responsibility for loss or damage
// arising from its use, including damage from virus.
//
// Please, note: This configuration information may be changed
// without any further notice.
// Casio Europe GmbH does not guarantee future compatibility. By 
// using this software you agree to these terms and conditions.
//
// System Requirements: Windows Mobile 6.x (DT-X30, IT-800)
// See also http://msdn.microsoft.com/en-us/library/bb431750.aspx
//
// Version 1.0.3.1
///////////////////////////////////////////////////////////////////

using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Calib;

namespace SoftkeysWM
{
    /// <summary>
    /// This samples shows how to assign new key codes.
    /// </summary>
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();

            ConfigureKeys();
        }

        private void MainForm_Closing(object sender, CancelEventArgs e)
        {
            int result;

            ConfigureKeys(false);

            // Disable any user settings.
            result = SystemLibNet.Api.SysSetUserDefineKeyState(false);
        }

        private void ConfigureKeys()
        {
            ConfigureKeys(true);
        }

        private void ConfigureKeys(bool init)
        {
            int result;

            // If the form has a main menu with two buttons (softkeys),
            // the left softkey is assigned to key code F1, and
            // the right softkey is assigned to key code F2.
            // However, hardware key "F2" is far away from the right softkey.
            // Hence, we swap "F2" with "F4" to make it more intuitive for the user.
            // Finally, hardware key "F4" will be the right softkey.
            if (init == true)
            {
                int[] keyBufferF2 = new int[16];
                int[] keyBufferF4 = new int[16];

                result = SystemLibNet.Api.SysGetDefaultKey(
                    SystemLibNet.Def.KEYID_F4,
                    keyBufferF2);

                result = SystemLibNet.Api.SysGetDefaultKey(
                    SystemLibNet.Def.KEYID_F2,
                    keyBufferF4);

                for (short i = SystemLibNet.Def.KEY_MODE_NUM; i <= SystemLibNet.Def.KEY_MODE_ALPHAS; i++)
                {
                    result = SystemLibNet.Api.SysSetUserDefineKey(
                        i,
                        SystemLibNet.Def.KEYID_F2,
                        keyBufferF2);

                    result = SystemLibNet.Api.SysSetUserDefineKey(
                        i,
                        SystemLibNet.Def.KEYID_F4,
                        keyBufferF4);
                }

                SystemLibNet.Api.SysSetFnKeyLock(true);
            }
            else
            {
                for (short i = SystemLibNet.Def.KEY_MODE_NUM; i <= SystemLibNet.Def.KEY_MODE_ALPHAS; i++)
                {
                    result = SystemLibNet.Api.SysDeleteUserDefineKeyEx(
                        i,
                        SystemLibNet.Def.KEYID_F2);

                    result = SystemLibNet.Api.SysDeleteUserDefineKeyEx(
                        i,
                        SystemLibNet.Def.KEYID_F4);
                }

                SystemLibNet.Api.SysSetFnKeyLock(false);
            }

            // Inform the keyboard driver about changes.
            result = SystemLibNet.Api.SysSetUserDefineKeyState(true);
        }

        private void menuLeft_Click(object sender, EventArgs e)
        {
            this.statusBar.Text = "Left softkey pressed.";
        }

        private void menuRight_Click(object sender, EventArgs e)
        {
            this.statusBar.Text = "Right softkey pressed.";
        }

        private void MainForm_KeyUp(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.F3:
                    this.statusBar.Text = "Key F3 pressed.";
                    break;
                case Keys.F4: // F4 was swapped with F2
                    this.statusBar.Text = "Key F2 pressed.";
                    break;
                default:
                    break;
            }
        }
    }
}